(***********************************************************************)
(*                                                                     *)
(*                             Pio (OCaml)                             *)
(*                                                                     *)
(*                    Polyglot Input/Output Library                    *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2005-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(*  $Id: main.ml,v 1.4 2014/01/10 19:22:11 fclement Exp $ *)

open Write_typed_value;;
open Write_communication;;

type output_mode =
   | Output_communication
   | Output_typed_value
;;

let { Uaref.get = get_output_mode; set = set_output_mode; } =
  Uaref.make_aref_single "output_mode" Output_communication
;;

let set_communication () = set_output_mode Output_communication;;
let set_typed_value () = set_output_mode Output_typed_value;;

Ucommand_option.user_add_all
  [
   Ucommand_option.of_regular
     {
      Ucommand_option.key = "--communication";
      spec = Arg.Unit set_communication;
      doc =
        "  Turn on the generation of a communication r/w test file.\
        \n\tThis is the default.\n";
     };
   
   Ucommand_option.of_regular
     {
      Ucommand_option.key = "--typed-value";
      spec = Arg.Unit set_typed_value;
      doc = "  Turn on the generation of a typed_value r/w test file.\n";
     };
  ]
;;

(* Check general write communications on a buffer *)

let write_and_flush write ob t =
  write ob t;
  Ubuffer.flush_buffer_on_stdout ob;
;;

let main () =
  Ucommand_option.parse ();
  let ob = Buffer.create 1024 in
  begin 
    if get_output_mode () = Output_typed_value
    then
      List.iter (write_and_flush write_typed_value ob) Gen_typed_values.list
    else
      List.iter (write_and_flush write_communication ob) Gen_communication.list
  end;
  exit 0
;;

main ();;
