CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                     C
C                              Ref-indic                              C
C                                                                     C
C                        Refinement indicators                        C
C                                                                     C
C               EPI Pomdapi, INRIA Paris - Rocquencourt               C
C                                                                     C
C  Copyright 2013-2014 INRIA.                                         C
C  Institut National de Recherche en Informatique et en Automatique.  C
C  All rights reserved. This file is distributed only by permission.  C
C                                                                     C
C  Hend Ben Ameur <hbenameur@yahoo.ca>                                C
C  Francois Clement <Francois.Clement@inria.fr>                       C
C  Pierre Weis <Pierre.Weis@inria.fr>                                 C
C                                                                     C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

C     $Id: worker_main.fpp,v 1.8 2014-03-14 15:47:26 fclement Exp $

#include "worker_constants.h"

      program worker_main
C     Main program.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
CCC      call pio_user_set_report_mode
CCC      call pio_user_set_debug_mode
CCC      call pio_set_report_mode
CCC      call pio_set_debug_mode
      
      call pio_user_set_message_prefix(10, '[Worker]: ')
      
      call pio_user_report_message('start user model')
      
      ier = 0
      initialized = .False.
      finished = .False.
      
      call pio_user_parse_config_file
      if (ier .ne. 0) then
         call pio_user_write_and_send_error_message
         stop
      endif
      
      call worker_loop
      if (ier .ne. 0) then
         call pio_user_write_and_send_error_message
         stop
      endif
      
      call pio_user_report_message('finish user model')
      
      end


      subroutine worker_loop
C     Infinite loop.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Local variables.
      character sbr*11, task_name*PIO_MAX_IDENT_LENGTH
      integer s_len, tc, len
      
C     External functions.
      logical pio_user_get_report_mode
      integer pio_get_communication_type
      
      s_len = 11
      sbr = 'worker_loop'
      
   10 continue
      
      call pio_receive_in_communication(PIO_STDIN)
      
      tc = pio_get_communication_type()
      
      if (tc .eq. PIO_TASK) then
         
         len = PIO_MAX_IDENT_LENGTH
         call pio_get_communication_name(len, task_name)
         
         if (pio_user_get_report_mode())
     +        write(PIO_USER_REPORT, *)
     +          '[Worker]: task "', task_name(1:len), '" received'
         
         if (task_name(1:len) .eq. 'init') then
            call worker_initialization
            if (ier .ne. 0) return
         else if (task_name(1:len) .eq. 'grad') then
            call worker_gradient_computation
            if (ier .ne. 0) return
         else if (task_name(1:len) .eq. 'optim') then
            call worker_optimization
            if (ier .ne. 0) return
         else if (task_name(1:len) .eq. 'final') then
            call worker_finalization
            if (ier .ne. 0) return
         else
            call pio_user_error_unbound_task(s_len, sbr, len, task_name)
            return
         endif
         
      else
         
         call pio_user_error_unbound_communication(s_len, sbr, tc)
         return
         
      endif
      
      if (.not. finished) goto 10
      
      return
      end


      subroutine worker_initialization
C     Initialization task.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Local variables.
      character sbr*21
      integer s_len, nargs
      integer pp1(WORKER_MAX_SIZE, WORKER_MAX_DIMENSION)
      integer lens1(WORKER_MAX_DIMENSION)
      FLOAT m1(WORKER_MAX_ZONE_NUMBER), cost1
      
C     External functions.
      integer pio_get_communication_number_of_values
      integer pio_get_int
      
      s_len = 21
      sbr = 'worker_initialization'
      
      call pio_user_set_message_prefix(23, '[Worker]: Task "init": ')
      
      call pio_user_report_message('started')
      
      nargs = pio_get_communication_number_of_values()
      call pio_user_check_number_of_values(s_len, sbr, 1, nargs)
      if (ier .ne. 0) return
      
      call pio_user_report_message('one value received')
      
      dim = pio_get_int()
      if (dim .gt. WORKER_MAX_DIMENSION) then
         call worker_error_too_large_dimension(s_len, sbr, dim)
         return
      endif
      
      call pio_user_report_message('dimension extracted')
      
      call initialization(pp1, lens1, m1)
      if (ier .ne. 0) return
      
      size = size_x * size_y
      if (size .gt. WORKER_MAX_SIZE) then
         call worker_error_too_large_size(s_len, sbr, size)
         return
      endif
      
      if (zone_number .gt. WORKER_MAX_ZONE_NUMBER) then
         call worker_error_too_large_zone_number
     +        (s_len, sbr, zone_number)
         return
      endif
      
      call optimization(pp1, lens1, m1, cost1)
      if (ier .ne. 0) return
      
      call pio_user_report_message('result computed')
      
      call pio_init_out_communication(PIO_RESULT, 5)
      call pio_add_int_couple(size_x, size_y)
      call pio_transpose_and_add_int_matrix
     +     (WORKER_MAX_SIZE, size, WORKER_MAX_DIMENSION, dim, pp1)
      call pio_add_int_vector(dim, lens1)
      call pio_add_float_vector(zone_number, m1)
      call pio_add_float(cost1)
      call pio_send_out_communication(PIO_STDOUT)
      
      call pio_user_report_message('result sent back')
      
      call pio_user_report_message('finished')
      
      initialized = .True.
      
      return
      end


      subroutine worker_gradient_computation
C     Gradient computation task.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Local variables.
      character sbr*27
      integer s_len, nargs, dim_loc, size_loc
      FLOAT p(WORKER_MAX_SIZE, WORKER_MAX_DIMENSION)
      FLOAT g(WORKER_MAX_SIZE, WORKER_MAX_DIMENSION)
      
C     External function.
      integer pio_get_communication_number_of_values
      
      s_len = 27
      sbr = 'worker_gradient_computation'
      
      call pio_user_set_message_prefix(23, '[Worker]: Task "grad": ')
      
      call pio_user_report_message('started')
      
      if (.not. initialized) then
         call pio_user_error_not_initialized(s_len, sbr)
         return
      endif
      
      nargs = pio_get_communication_number_of_values()
      call pio_user_check_number_of_values(s_len, sbr, 1, nargs)
      if (ier .ne. 0) return
      
      call pio_user_report_message('one value received')
      
      call pio_get_and_transpose_float_matrix
     +     (WORKER_MAX_SIZE, size_loc, WORKER_MAX_DIMENSION, dim_loc, p)
      
      call pio_user_report_message('fine parameter extracted')
      
      call worker_check_dimension(s_len, sbr, dim_loc)
      if (ier .ne. 0) return
      call worker_check_size(s_len, sbr, size_loc)
      if (ier .ne. 0) return
      
      call gradient_computation(p, g)
      if (ier .ne. 0) return
      
      call pio_user_report_message('result computed')
      
      call pio_init_out_communication(PIO_RESULT, 1)
      call pio_transpose_and_add_float_matrix
     +     (WORKER_MAX_SIZE, size, WORKER_MAX_DIMENSION, dim, g)
      call pio_send_out_communication(PIO_STDOUT)
      
      call pio_user_report_message('result sent back')
      
      call pio_user_report_message('finished')
      
      return
      end


      subroutine worker_optimization
C     Optimization task.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Local variables.
      character sbr*19
      integer s_len, nargs, dim_loc, size_loc, zone_number_loc
      integer pp(WORKER_MAX_SIZE, WORKER_MAX_DIMENSION)
      integer lens(WORKER_MAX_DIMENSION)
      FLOAT m(WORKER_MAX_ZONE_NUMBER), cost
      
C     External function.
      integer pio_get_communication_number_of_values
      
      s_len = 19
      sbr = 'worker_optimization'
      
      call pio_user_set_message_prefix(24, '[Worker]: Task "optim": ')
      
      call pio_user_report_message('started')
      
      if (.not. initialized) then
         call pio_user_error_not_initialized(s_len, sbr)
         return
      endif
      
      nargs = pio_get_communication_number_of_values()
      call pio_user_check_number_of_values(s_len, sbr, 3, nargs)
      if (ier .ne. 0) return
      
      call pio_user_report_message('three values received')
      
      call pio_get_and_transpose_int_matrix
     +     (WORKER_MAX_SIZE, size_loc, WORKER_MAX_DIMENSION, dim_loc, pp)
      
      call pio_user_report_message('partition extracted')
      
      call worker_check_dimension(s_len, sbr, dim_loc)
      if (ier .ne. 0) return
      call worker_check_size(s_len, sbr, size_loc)
      if (ier .ne. 0) return
      
      dim_loc = WORKER_MAX_DIMENSION
      call pio_get_int_vector(dim_loc, lens)
      
      call pio_user_report_message('coarse parameter lengths extracted')
      
      call worker_check_dimension(s_len, sbr, dim_loc)
      if (ier .ne. 0) return
      call worker_check_partition(s_len, sbr, pp, lens)
      if (ier .ne. 0) return
      call worker_compute_zone_number(lens)
      
      zone_number_loc = WORKER_MAX_ZONE_NUMBER
      call pio_get_float_vector(zone_number_loc, m)
      
      call pio_user_report_message('initial coarse parameter extracted')
      
      call worker_check_zone_number(s_len, sbr, zone_number_loc)
      if (ier .ne. 0) return
      
      call optimization(pp, lens, m, cost)
      if (ier .ne. 0) return
      
      call pio_user_report_message('result computed')
      
      call pio_init_out_communication(PIO_RESULT, 3)
      call pio_add_int_vector(dim, lens)
      call pio_add_float_vector(zone_number, m)
      call pio_add_float(cost)
      call pio_send_out_communication(PIO_STDOUT)
      
      call pio_user_report_message('result sent back ')
      
      call pio_user_report_message('finished')
      
      return
      end


      subroutine worker_finalization
C     Finalization task.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Local variables.
      character sbr*19
      integer s_len, nargs, dim_loc, size_loc
      FLOAT p(WORKER_MAX_SIZE, WORKER_MAX_DIMENSION)
      
C     External function.
      integer pio_get_communication_number_of_values
      
      s_len = 19
      sbr = 'worker_finalization'
      
      call pio_user_set_message_prefix(24, '[Worker]: Task "final": ')
      
      call pio_user_report_message('started')
      
      if (.not. initialized) then
         call pio_user_error_not_initialized(s_len, sbr)
         return
      endif
      
      nargs = pio_get_communication_number_of_values()
      call pio_user_check_number_of_values(s_len, sbr, 1, nargs)
      if (ier .ne. 0) return
      
      call pio_user_report_message('one value received')
      
      call pio_get_and_transpose_float_matrix
     +     (WORKER_MAX_SIZE, size_loc, WORKER_MAX_DIMENSION, dim_loc, p)
      
      call pio_user_report_message('fine parameter extracted')
      
      call worker_check_dimension(s_len, sbr, dim_loc)
      if (ier .ne. 0) return
      call worker_check_size(s_len, sbr, size_loc)
      if (ier .ne. 0) return
      
      call finalization(p)
      if (ier .ne. 0) return
      
      call pio_user_report_message('result computed')
      
      call pio_init_out_communication(PIO_RESULT, 1)
      call pio_add_string(10, '\nOK, bye!\n')
      call pio_send_out_communication(PIO_STDOUT)
      
      call pio_user_report_message('result sent back')
      
      call pio_user_report_message('finished')
      
      finished = .True.
      
      return
      end


      subroutine worker_compute_zone_number(lens)
C     Compute zone number.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Input argument.
      integer lens(WORKER_MAX_DIMENSION)
      
C     Local variable.
      integer i
      
      zone_number = 0
      do i = 1, dim
         zone_number = zone_number + lens(i)
      enddo
      
      return
      end


      subroutine worker_check_partition(s_len, sbr, pp, lens)
C     Check partition.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Input arguments.
      character sbr*(*)
      integer s_len
      integer pp(WORKER_MAX_SIZE, WORKER_MAX_DIMENSION)
      integer lens(WORKER_MAX_DIMENSION)
      
C     Local variables
      integer i, j, len_j, pp_ij
      
      do j = 1, dim
         len_j = lens(j)
         do i = 1, size
            pp_ij = pp(i, j)
            if (.not. ((0 .le. pp_ij) .and. (pp_ij .lt. len_j))) then
               call worker_error_out_of_bounds_zone_number
     +              (s_len, sbr, j, i, len_j, pp_ij)
               return
            endif
         enddo
      enddo
      
      return
      end


      subroutine worker_check_dimension(s_len, sbr, dim_loc)
C     Check dimension.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Input arguments.
      character sbr*(*)
      integer s_len, dim_loc
      
      if (dim_loc .ne. dim) then
         call worker_error_wrong_dimension(s_len, sbr, dim, dim_loc)
      endif
      
      return
      end


      subroutine worker_check_size(s_len, sbr, size_loc)
C     Check size.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Input arguments.
      character sbr*(*)
      integer s_len, size_loc
      
      if (size_loc .ne. size) then
         call worker_error_wrong_size(s_len, sbr, size, size_loc)
      endif
      
      return
      end


      subroutine worker_check_zone_number(s_len, sbr, zone_number_loc)
C     Check zone number.
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      include 'worker_init_definition.fh'
      
C     Input arguments.
      character sbr*(*)
      integer s_len, zone_number_loc
      
      if (zone_number_loc .ne. zone_number) then
         call worker_error_wrong_zone_number
     +        (s_len, sbr, zone_number, zone_number_loc)
      endif
      
      return
      end
